@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<APB1EN_SPEC>> for R {
+impl From<crate::R<APB1EN_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<APB1EN_SPEC>) -> Self {
         R(reader)
     }
@@ -27,57 +28,16 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<APB1EN_SPEC>> for W {
+impl From<crate::W<APB1EN_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<APB1EN_SPEC>) -> Self {
         W(writer)
     }
 }
-#[doc = "TIMER1 timer clock enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TIMER1EN_A {
-    #[doc = "0: The selected clock is disabled"]
-    DISABLED = 0,
-    #[doc = "1: The selected clock is enabled"]
-    ENABLED = 1,
-}
-impl From<TIMER1EN_A> for bool {
-    #[inline(always)]
-    fn from(variant: TIMER1EN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "TIMER1 timer clock enable"]
+pub type TIMER1EN_A = CECEN_A;
 #[doc = "Field `TIMER1EN` reader - TIMER1 timer clock enable"]
-pub struct TIMER1EN_R(crate::FieldReader<bool, TIMER1EN_A>);
-impl TIMER1EN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        TIMER1EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> TIMER1EN_A {
-        match self.bits {
-            false => TIMER1EN_A::DISABLED,
-            true => TIMER1EN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == TIMER1EN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == TIMER1EN_A::ENABLED
-    }
-}
-impl core::ops::Deref for TIMER1EN_R {
-    type Target = crate::FieldReader<bool, TIMER1EN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TIMER1EN_R = CECEN_R;
 #[doc = "Field `TIMER1EN` writer - TIMER1 timer clock enable"]
 pub struct TIMER1EN_W<'a> {
     w: &'a mut W,
@@ -116,9 +76,9 @@ impl<'a> TIMER1EN_W<'a> {
     }
 }
 #[doc = "TIMER2 timer clock enable"]
-pub type TIMER2EN_A = TIMER1EN_A;
+pub type TIMER2EN_A = CECEN_A;
 #[doc = "Field `TIMER2EN` reader - TIMER2 timer clock enable"]
-pub type TIMER2EN_R = TIMER1EN_R;
+pub type TIMER2EN_R = CECEN_R;
 #[doc = "Field `TIMER2EN` writer - TIMER2 timer clock enable"]
 pub struct TIMER2EN_W<'a> {
     w: &'a mut W,
@@ -157,9 +117,9 @@ impl<'a> TIMER2EN_W<'a> {
     }
 }
 #[doc = "TIMER5 timer clock enable"]
-pub type TIMER5EN_A = TIMER1EN_A;
+pub type TIMER5EN_A = CECEN_A;
 #[doc = "Field `TIMER5EN` reader - TIMER5 timer clock enable"]
-pub type TIMER5EN_R = TIMER1EN_R;
+pub type TIMER5EN_R = CECEN_R;
 #[doc = "Field `TIMER5EN` writer - TIMER5 timer clock enable"]
 pub struct TIMER5EN_W<'a> {
     w: &'a mut W,
@@ -198,9 +158,9 @@ impl<'a> TIMER5EN_W<'a> {
     }
 }
 #[doc = "TIMER13 timer clock enable"]
-pub type TIMER13EN_A = TIMER1EN_A;
+pub type TIMER13EN_A = CECEN_A;
 #[doc = "Field `TIMER13EN` reader - TIMER13 timer clock enable"]
-pub type TIMER13EN_R = TIMER1EN_R;
+pub type TIMER13EN_R = CECEN_R;
 #[doc = "Field `TIMER13EN` writer - TIMER13 timer clock enable"]
 pub struct TIMER13EN_W<'a> {
     w: &'a mut W,
@@ -239,9 +199,9 @@ impl<'a> TIMER13EN_W<'a> {
     }
 }
 #[doc = "Window watchdog timer clock enable"]
-pub type WWDGTEN_A = TIMER1EN_A;
+pub type WWDGTEN_A = CECEN_A;
 #[doc = "Field `WWDGTEN` reader - Window watchdog timer clock enable"]
-pub type WWDGTEN_R = TIMER1EN_R;
+pub type WWDGTEN_R = CECEN_R;
 #[doc = "Field `WWDGTEN` writer - Window watchdog timer clock enable"]
 pub struct WWDGTEN_W<'a> {
     w: &'a mut W,
@@ -280,9 +240,9 @@ impl<'a> WWDGTEN_W<'a> {
     }
 }
 #[doc = "SPI1 clock enable"]
-pub type SPI1EN_A = TIMER1EN_A;
+pub type SPI1EN_A = CECEN_A;
 #[doc = "Field `SPI1EN` reader - SPI1 clock enable"]
-pub type SPI1EN_R = TIMER1EN_R;
+pub type SPI1EN_R = CECEN_R;
 #[doc = "Field `SPI1EN` writer - SPI1 clock enable"]
 pub struct SPI1EN_W<'a> {
     w: &'a mut W,
@@ -321,9 +281,9 @@ impl<'a> SPI1EN_W<'a> {
     }
 }
 #[doc = "SPI2 clock enable"]
-pub type SPI2EN_A = TIMER1EN_A;
+pub type SPI2EN_A = CECEN_A;
 #[doc = "Field `SPI2EN` reader - SPI2 clock enable"]
-pub type SPI2EN_R = TIMER1EN_R;
+pub type SPI2EN_R = CECEN_R;
 #[doc = "Field `SPI2EN` writer - SPI2 clock enable"]
 pub struct SPI2EN_W<'a> {
     w: &'a mut W,
@@ -362,9 +322,9 @@ impl<'a> SPI2EN_W<'a> {
     }
 }
 #[doc = "USART1 clock enable"]
-pub type USART1EN_A = TIMER1EN_A;
+pub type USART1EN_A = CECEN_A;
 #[doc = "Field `USART1EN` reader - USART1 clock enable"]
-pub type USART1EN_R = TIMER1EN_R;
+pub type USART1EN_R = CECEN_R;
 #[doc = "Field `USART1EN` writer - USART1 clock enable"]
 pub struct USART1EN_W<'a> {
     w: &'a mut W,
@@ -403,9 +363,9 @@ impl<'a> USART1EN_W<'a> {
     }
 }
 #[doc = "I2C0 clock enable"]
-pub type I2C0EN_A = TIMER1EN_A;
+pub type I2C0EN_A = CECEN_A;
 #[doc = "Field `I2C0EN` reader - I2C0 clock enable"]
-pub type I2C0EN_R = TIMER1EN_R;
+pub type I2C0EN_R = CECEN_R;
 #[doc = "Field `I2C0EN` writer - I2C0 clock enable"]
 pub struct I2C0EN_W<'a> {
     w: &'a mut W,
@@ -444,9 +404,9 @@ impl<'a> I2C0EN_W<'a> {
     }
 }
 #[doc = "I2C1 clock enable"]
-pub type I2C1EN_A = TIMER1EN_A;
+pub type I2C1EN_A = CECEN_A;
 #[doc = "Field `I2C1EN` reader - I2C1 clock enable"]
-pub type I2C1EN_R = TIMER1EN_R;
+pub type I2C1EN_R = CECEN_R;
 #[doc = "Field `I2C1EN` writer - I2C1 clock enable"]
 pub struct I2C1EN_W<'a> {
     w: &'a mut W,
@@ -485,9 +445,9 @@ impl<'a> I2C1EN_W<'a> {
     }
 }
 #[doc = "USBD clock enable"]
-pub type USBDEN_A = TIMER1EN_A;
+pub type USBDEN_A = CECEN_A;
 #[doc = "Field `USBDEN` reader - USBD clock enable"]
-pub type USBDEN_R = TIMER1EN_R;
+pub type USBDEN_R = CECEN_R;
 #[doc = "Field `USBDEN` writer - USBD clock enable"]
 pub struct USBDEN_W<'a> {
     w: &'a mut W,
@@ -526,9 +486,9 @@ impl<'a> USBDEN_W<'a> {
     }
 }
 #[doc = "Power interface clock enable"]
-pub type PMUEN_A = TIMER1EN_A;
+pub type PMUEN_A = CECEN_A;
 #[doc = "Field `PMUEN` reader - Power interface clock enable"]
-pub type PMUEN_R = TIMER1EN_R;
+pub type PMUEN_R = CECEN_R;
 #[doc = "Field `PMUEN` writer - Power interface clock enable"]
 pub struct PMUEN_W<'a> {
     w: &'a mut W,
@@ -567,9 +527,9 @@ impl<'a> PMUEN_W<'a> {
     }
 }
 #[doc = "DAC interface clock enable"]
-pub type DACEN_A = TIMER1EN_A;
+pub type DACEN_A = CECEN_A;
 #[doc = "Field `DACEN` reader - DAC interface clock enable"]
-pub type DACEN_R = TIMER1EN_R;
+pub type DACEN_R = CECEN_R;
 #[doc = "Field `DACEN` writer - DAC interface clock enable"]
 pub struct DACEN_W<'a> {
     w: &'a mut W,
@@ -607,10 +567,52 @@ impl<'a> DACEN_W<'a> {
         self.w
     }
 }
-#[doc = "HDMI CEC interface clock enable"]
-pub type CECEN_A = TIMER1EN_A;
+#[doc = "HDMI CEC interface clock enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CECEN_A {
+    #[doc = "0: The selected clock is disabled"]
+    DISABLED = 0,
+    #[doc = "1: The selected clock is enabled"]
+    ENABLED = 1,
+}
+impl From<CECEN_A> for bool {
+    #[inline(always)]
+    fn from(variant: CECEN_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `CECEN` reader - HDMI CEC interface clock enable"]
-pub type CECEN_R = TIMER1EN_R;
+pub struct CECEN_R(crate::FieldReader<bool, CECEN_A>);
+impl CECEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CECEN_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> CECEN_A {
+        match self.bits {
+            false => CECEN_A::DISABLED,
+            true => CECEN_A::ENABLED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `DISABLED`"]
+    #[inline(always)]
+    pub fn is_disabled(&self) -> bool {
+        **self == CECEN_A::DISABLED
+    }
+    #[doc = "Checks if the value of the field is `ENABLED`"]
+    #[inline(always)]
+    pub fn is_enabled(&self) -> bool {
+        **self == CECEN_A::ENABLED
+    }
+}
+impl core::ops::Deref for CECEN_R {
+    type Target = crate::FieldReader<bool, CECEN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `CECEN` writer - HDMI CEC interface clock enable"]
 pub struct CECEN_W<'a> {
     w: &'a mut W,
@@ -792,6 +794,7 @@ impl W {
         CECEN_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
