@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<DMAINTEN_SPEC>> for R {
+impl From<crate::R<DMAINTEN_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<DMAINTEN_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<DMAINTEN_SPEC>> for W {
+impl From<crate::W<DMAINTEN_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<DMAINTEN_SPEC>) -> Self {
         W(writer)
     }
@@ -115,52 +117,10 @@ impl<'a> TRGDEN_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 Capture/Compare DMA request enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3DEN_A {
-    #[doc = "0: Capture/compare DMA request disabled"]
-    DISABLED = 0,
-    #[doc = "1: Capture/compare DMA request enabled"]
-    ENABLED = 1,
-}
-impl From<CH3DEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3DEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 Capture/Compare DMA request enable"]
+pub type CH3DEN_A = CH0DEN_A;
 #[doc = "Field `CH3DEN` reader - Channel 3 Capture/Compare DMA request enable"]
-pub struct CH3DEN_R(crate::FieldReader<bool, CH3DEN_A>);
-impl CH3DEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3DEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3DEN_A {
-        match self.bits {
-            false => CH3DEN_A::DISABLED,
-            true => CH3DEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH3DEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH3DEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH3DEN_R {
-    type Target = crate::FieldReader<bool, CH3DEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3DEN_R = CH0DEN_R;
 #[doc = "Field `CH3DEN` writer - Channel 3 Capture/Compare DMA request enable"]
 pub struct CH3DEN_W<'a> {
     w: &'a mut W,
@@ -199,9 +159,9 @@ impl<'a> CH3DEN_W<'a> {
     }
 }
 #[doc = "Channel 2 Capture/Compare DMA request enable"]
-pub type CH2DEN_A = CH3DEN_A;
+pub type CH2DEN_A = CH0DEN_A;
 #[doc = "Field `CH2DEN` reader - Channel 2 Capture/Compare DMA request enable"]
-pub type CH2DEN_R = CH3DEN_R;
+pub type CH2DEN_R = CH0DEN_R;
 #[doc = "Field `CH2DEN` writer - Channel 2 Capture/Compare DMA request enable"]
 pub struct CH2DEN_W<'a> {
     w: &'a mut W,
@@ -240,9 +200,9 @@ impl<'a> CH2DEN_W<'a> {
     }
 }
 #[doc = "Channel 1 Capture/Compare DMA request enable"]
-pub type CH1DEN_A = CH3DEN_A;
+pub type CH1DEN_A = CH0DEN_A;
 #[doc = "Field `CH1DEN` reader - Channel 1 Capture/Compare DMA request enable"]
-pub type CH1DEN_R = CH3DEN_R;
+pub type CH1DEN_R = CH0DEN_R;
 #[doc = "Field `CH1DEN` writer - Channel 1 Capture/Compare DMA request enable"]
 pub struct CH1DEN_W<'a> {
     w: &'a mut W,
@@ -280,10 +240,52 @@ impl<'a> CH1DEN_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 0 Capture/Compare DMA request enable"]
-pub type CH0DEN_A = CH3DEN_A;
+#[doc = "Channel 0 Capture/Compare DMA request enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CH0DEN_A {
+    #[doc = "0: Capture/compare DMA request disabled"]
+    DISABLED = 0,
+    #[doc = "1: Capture/compare DMA request enabled"]
+    ENABLED = 1,
+}
+impl From<CH0DEN_A> for bool {
+    #[inline(always)]
+    fn from(variant: CH0DEN_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `CH0DEN` reader - Channel 0 Capture/Compare DMA request enable"]
-pub type CH0DEN_R = CH3DEN_R;
+pub struct CH0DEN_R(crate::FieldReader<bool, CH0DEN_A>);
+impl CH0DEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CH0DEN_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> CH0DEN_A {
+        match self.bits {
+            false => CH0DEN_A::DISABLED,
+            true => CH0DEN_A::ENABLED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `DISABLED`"]
+    #[inline(always)]
+    pub fn is_disabled(&self) -> bool {
+        **self == CH0DEN_A::DISABLED
+    }
+    #[doc = "Checks if the value of the field is `ENABLED`"]
+    #[inline(always)]
+    pub fn is_enabled(&self) -> bool {
+        **self == CH0DEN_A::ENABLED
+    }
+}
+impl core::ops::Deref for CH0DEN_R {
+    type Target = crate::FieldReader<bool, CH0DEN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `CH0DEN` writer - Channel 0 Capture/Compare DMA request enable"]
 pub struct CH0DEN_W<'a> {
     w: &'a mut W,
@@ -816,6 +818,7 @@ impl W {
         UPIE_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
         self.0.bits(bits);
         self
