@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<CHCTL2_SPEC>> for R {
+impl From<crate::R<CHCTL2_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<CHCTL2_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<CHCTL2_SPEC>> for W {
+impl From<crate::W<CHCTL2_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<CHCTL2_SPEC>) -> Self {
         W(writer)
     }
@@ -240,6 +242,7 @@ impl W {
         CH0EN_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
         self.0.bits(bits);
         self
