@@ -13,7 +13,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SWEVG_SPEC>> for W {
+impl From<crate::W<SWEVG_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SWEVG_SPEC>) -> Self {
         W(writer)
     }
@@ -176,6 +177,7 @@ impl W {
         UPG_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
         self.0.bits(bits);
         self
