@@ -13,7 +13,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<INTC_SPEC>> for W {
+impl From<crate::W<INTC_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<INTC_SPEC>) -> Self {
         W(writer)
     }
@@ -608,6 +609,7 @@ impl W {
         PEC_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
