@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<APB1RST_SPEC>> for R {
+impl From<crate::R<APB1RST_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<APB1RST_SPEC>) -> Self {
         R(reader)
     }
@@ -27,50 +28,16 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<APB1RST_SPEC>> for W {
+impl From<crate::W<APB1RST_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<APB1RST_SPEC>) -> Self {
         W(writer)
     }
 }
-#[doc = "TIMER1 timer reset\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TIMER1RST_A {
-    #[doc = "1: Reset the selected module"]
-    RESET = 1,
-}
-impl From<TIMER1RST_A> for bool {
-    #[inline(always)]
-    fn from(variant: TIMER1RST_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "TIMER1 timer reset"]
+pub type TIMER1RST_A = CECRST_A;
 #[doc = "Field `TIMER1RST` reader - TIMER1 timer reset"]
-pub struct TIMER1RST_R(crate::FieldReader<bool, TIMER1RST_A>);
-impl TIMER1RST_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        TIMER1RST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> Option<TIMER1RST_A> {
-        match self.bits {
-            true => Some(TIMER1RST_A::RESET),
-            _ => None,
-        }
-    }
-    #[doc = "Checks if the value of the field is `RESET`"]
-    #[inline(always)]
-    pub fn is_reset(&self) -> bool {
-        **self == TIMER1RST_A::RESET
-    }
-}
-impl core::ops::Deref for TIMER1RST_R {
-    type Target = crate::FieldReader<bool, TIMER1RST_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TIMER1RST_R = CECRST_R;
 #[doc = "Field `TIMER1RST` writer - TIMER1 timer reset"]
 pub struct TIMER1RST_W<'a> {
     w: &'a mut W,
@@ -104,9 +71,9 @@ impl<'a> TIMER1RST_W<'a> {
     }
 }
 #[doc = "TIMER2 timer reset"]
-pub type TIMER2RST_A = TIMER1RST_A;
+pub type TIMER2RST_A = CECRST_A;
 #[doc = "Field `TIMER2RST` reader - TIMER2 timer reset"]
-pub type TIMER2RST_R = TIMER1RST_R;
+pub type TIMER2RST_R = CECRST_R;
 #[doc = "Field `TIMER2RST` writer - TIMER2 timer reset"]
 pub struct TIMER2RST_W<'a> {
     w: &'a mut W,
@@ -140,9 +107,9 @@ impl<'a> TIMER2RST_W<'a> {
     }
 }
 #[doc = "TIMER5 timer reset"]
-pub type TIMER5RST_A = TIMER1RST_A;
+pub type TIMER5RST_A = CECRST_A;
 #[doc = "Field `TIMER5RST` reader - TIMER5 timer reset"]
-pub type TIMER5RST_R = TIMER1RST_R;
+pub type TIMER5RST_R = CECRST_R;
 #[doc = "Field `TIMER5RST` writer - TIMER5 timer reset"]
 pub struct TIMER5RST_W<'a> {
     w: &'a mut W,
@@ -176,9 +143,9 @@ impl<'a> TIMER5RST_W<'a> {
     }
 }
 #[doc = "TIMER13 timer reset"]
-pub type TIMER13RST_A = TIMER1RST_A;
+pub type TIMER13RST_A = CECRST_A;
 #[doc = "Field `TIMER13RST` reader - TIMER13 timer reset"]
-pub type TIMER13RST_R = TIMER1RST_R;
+pub type TIMER13RST_R = CECRST_R;
 #[doc = "Field `TIMER13RST` writer - TIMER13 timer reset"]
 pub struct TIMER13RST_W<'a> {
     w: &'a mut W,
@@ -212,9 +179,9 @@ impl<'a> TIMER13RST_W<'a> {
     }
 }
 #[doc = "Window watchdog timer reset"]
-pub type WWDGTRST_A = TIMER1RST_A;
+pub type WWDGTRST_A = CECRST_A;
 #[doc = "Field `WWDGTRST` reader - Window watchdog timer reset"]
-pub type WWDGTRST_R = TIMER1RST_R;
+pub type WWDGTRST_R = CECRST_R;
 #[doc = "Field `WWDGTRST` writer - Window watchdog timer reset"]
 pub struct WWDGTRST_W<'a> {
     w: &'a mut W,
@@ -248,9 +215,9 @@ impl<'a> WWDGTRST_W<'a> {
     }
 }
 #[doc = "SPI1 reset"]
-pub type SPI1RST_A = TIMER1RST_A;
+pub type SPI1RST_A = CECRST_A;
 #[doc = "Field `SPI1RST` reader - SPI1 reset"]
-pub type SPI1RST_R = TIMER1RST_R;
+pub type SPI1RST_R = CECRST_R;
 #[doc = "Field `SPI1RST` writer - SPI1 reset"]
 pub struct SPI1RST_W<'a> {
     w: &'a mut W,
@@ -284,9 +251,9 @@ impl<'a> SPI1RST_W<'a> {
     }
 }
 #[doc = "SPI2 reset"]
-pub type SPI2RST_A = TIMER1RST_A;
+pub type SPI2RST_A = CECRST_A;
 #[doc = "Field `SPI2RST` reader - SPI2 reset"]
-pub type SPI2RST_R = TIMER1RST_R;
+pub type SPI2RST_R = CECRST_R;
 #[doc = "Field `SPI2RST` writer - SPI2 reset"]
 pub struct SPI2RST_W<'a> {
     w: &'a mut W,
@@ -320,9 +287,9 @@ impl<'a> SPI2RST_W<'a> {
     }
 }
 #[doc = "USART1 reset"]
-pub type USART1RST_A = TIMER1RST_A;
+pub type USART1RST_A = CECRST_A;
 #[doc = "Field `USART1RST` reader - USART1 reset"]
-pub type USART1RST_R = TIMER1RST_R;
+pub type USART1RST_R = CECRST_R;
 #[doc = "Field `USART1RST` writer - USART1 reset"]
 pub struct USART1RST_W<'a> {
     w: &'a mut W,
@@ -356,9 +323,9 @@ impl<'a> USART1RST_W<'a> {
     }
 }
 #[doc = "I2C0 reset"]
-pub type I2C0RST_A = TIMER1RST_A;
+pub type I2C0RST_A = CECRST_A;
 #[doc = "Field `I2C0RST` reader - I2C0 reset"]
-pub type I2C0RST_R = TIMER1RST_R;
+pub type I2C0RST_R = CECRST_R;
 #[doc = "Field `I2C0RST` writer - I2C0 reset"]
 pub struct I2C0RST_W<'a> {
     w: &'a mut W,
@@ -392,9 +359,9 @@ impl<'a> I2C0RST_W<'a> {
     }
 }
 #[doc = "I2C1 reset"]
-pub type I2C1RST_A = TIMER1RST_A;
+pub type I2C1RST_A = CECRST_A;
 #[doc = "Field `I2C1RST` reader - I2C1 reset"]
-pub type I2C1RST_R = TIMER1RST_R;
+pub type I2C1RST_R = CECRST_R;
 #[doc = "Field `I2C1RST` writer - I2C1 reset"]
 pub struct I2C1RST_W<'a> {
     w: &'a mut W,
@@ -428,9 +395,9 @@ impl<'a> I2C1RST_W<'a> {
     }
 }
 #[doc = "USBD reset"]
-pub type USBDRST_A = TIMER1RST_A;
+pub type USBDRST_A = CECRST_A;
 #[doc = "Field `USBDRST` reader - USBD reset"]
-pub type USBDRST_R = TIMER1RST_R;
+pub type USBDRST_R = CECRST_R;
 #[doc = "Field `USBDRST` writer - USBD reset"]
 pub struct USBDRST_W<'a> {
     w: &'a mut W,
@@ -464,9 +431,9 @@ impl<'a> USBDRST_W<'a> {
     }
 }
 #[doc = "Power control reset"]
-pub type PMURST_A = TIMER1RST_A;
+pub type PMURST_A = CECRST_A;
 #[doc = "Field `PMURST` reader - Power control reset"]
-pub type PMURST_R = TIMER1RST_R;
+pub type PMURST_R = CECRST_R;
 #[doc = "Field `PMURST` writer - Power control reset"]
 pub struct PMURST_W<'a> {
     w: &'a mut W,
@@ -500,9 +467,9 @@ impl<'a> PMURST_W<'a> {
     }
 }
 #[doc = "DAC reset"]
-pub type DACRST_A = TIMER1RST_A;
+pub type DACRST_A = CECRST_A;
 #[doc = "Field `DACRST` reader - DAC reset"]
-pub type DACRST_R = TIMER1RST_R;
+pub type DACRST_R = CECRST_R;
 #[doc = "Field `DACRST` writer - DAC reset"]
 pub struct DACRST_W<'a> {
     w: &'a mut W,
@@ -535,10 +502,45 @@ impl<'a> DACRST_W<'a> {
         self.w
     }
 }
-#[doc = "HDMI CEC reset"]
-pub type CECRST_A = TIMER1RST_A;
+#[doc = "HDMI CEC reset\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CECRST_A {
+    #[doc = "1: Reset the selected module"]
+    RESET = 1,
+}
+impl From<CECRST_A> for bool {
+    #[inline(always)]
+    fn from(variant: CECRST_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `CECRST` reader - HDMI CEC reset"]
-pub type CECRST_R = TIMER1RST_R;
+pub struct CECRST_R(crate::FieldReader<bool, CECRST_A>);
+impl CECRST_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CECRST_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> Option<CECRST_A> {
+        match self.bits {
+            true => Some(CECRST_A::RESET),
+            _ => None,
+        }
+    }
+    #[doc = "Checks if the value of the field is `RESET`"]
+    #[inline(always)]
+    pub fn is_reset(&self) -> bool {
+        **self == CECRST_A::RESET
+    }
+}
+impl core::ops::Deref for CECRST_R {
+    type Target = crate::FieldReader<bool, CECRST_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `CECRST` writer - HDMI CEC reset"]
 pub struct CECRST_W<'a> {
     w: &'a mut W,
@@ -715,6 +717,7 @@ impl W {
         CECRST_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
