@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<CTL0_SPEC>> for R {
+impl From<crate::R<CTL0_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<CTL0_SPEC>) -> Self {
         R(reader)
     }
@@ -27,57 +28,16 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<CTL0_SPEC>> for W {
+impl From<crate::W<CTL0_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<CTL0_SPEC>) -> Self {
         W(writer)
     }
 }
-#[doc = "Internal High Speed oscillator Enable\n\nValue on reset: 1"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum IRC8MEN_A {
-    #[doc = "0: Clock Off"]
-    OFF = 0,
-    #[doc = "1: Clock On"]
-    ON = 1,
-}
-impl From<IRC8MEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: IRC8MEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Internal High Speed oscillator Enable"]
+pub type IRC8MEN_A = HXTALEN_A;
 #[doc = "Field `IRC8MEN` reader - Internal High Speed oscillator Enable"]
-pub struct IRC8MEN_R(crate::FieldReader<bool, IRC8MEN_A>);
-impl IRC8MEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        IRC8MEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> IRC8MEN_A {
-        match self.bits {
-            false => IRC8MEN_A::OFF,
-            true => IRC8MEN_A::ON,
-        }
-    }
-    #[doc = "Checks if the value of the field is `OFF`"]
-    #[inline(always)]
-    pub fn is_off(&self) -> bool {
-        **self == IRC8MEN_A::OFF
-    }
-    #[doc = "Checks if the value of the field is `ON`"]
-    #[inline(always)]
-    pub fn is_on(&self) -> bool {
-        **self == IRC8MEN_A::ON
-    }
-}
-impl core::ops::Deref for IRC8MEN_R {
-    type Target = crate::FieldReader<bool, IRC8MEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type IRC8MEN_R = HXTALEN_R;
 #[doc = "Field `IRC8MEN` writer - Internal High Speed oscillator Enable"]
 pub struct IRC8MEN_W<'a> {
     w: &'a mut W,
@@ -201,10 +161,52 @@ impl core::ops::Deref for IRC8MCALIB_R {
         &self.0
     }
 }
-#[doc = "External High Speed oscillator Enable"]
-pub type HXTALEN_A = IRC8MEN_A;
+#[doc = "External High Speed oscillator Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum HXTALEN_A {
+    #[doc = "0: Clock Off"]
+    OFF = 0,
+    #[doc = "1: Clock On"]
+    ON = 1,
+}
+impl From<HXTALEN_A> for bool {
+    #[inline(always)]
+    fn from(variant: HXTALEN_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `HXTALEN` reader - External High Speed oscillator Enable"]
-pub type HXTALEN_R = IRC8MEN_R;
+pub struct HXTALEN_R(crate::FieldReader<bool, HXTALEN_A>);
+impl HXTALEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        HXTALEN_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> HXTALEN_A {
+        match self.bits {
+            false => HXTALEN_A::OFF,
+            true => HXTALEN_A::ON,
+        }
+    }
+    #[doc = "Checks if the value of the field is `OFF`"]
+    #[inline(always)]
+    pub fn is_off(&self) -> bool {
+        **self == HXTALEN_A::OFF
+    }
+    #[doc = "Checks if the value of the field is `ON`"]
+    #[inline(always)]
+    pub fn is_on(&self) -> bool {
+        **self == HXTALEN_A::ON
+    }
+}
+impl core::ops::Deref for HXTALEN_R {
+    type Target = crate::FieldReader<bool, HXTALEN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `HXTALEN` writer - External High Speed oscillator Enable"]
 pub struct HXTALEN_W<'a> {
     w: &'a mut W,
@@ -455,9 +457,9 @@ impl<'a> CKMEN_W<'a> {
     }
 }
 #[doc = "PLL enable"]
-pub type PLLEN_A = IRC8MEN_A;
+pub type PLLEN_A = HXTALEN_A;
 #[doc = "Field `PLLEN` reader - PLL enable"]
-pub type PLLEN_R = IRC8MEN_R;
+pub type PLLEN_R = HXTALEN_R;
 #[doc = "Field `PLLEN` writer - PLL enable"]
 pub struct PLLEN_W<'a> {
     w: &'a mut W,
@@ -625,6 +627,7 @@ impl W {
         PLLEN_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
