@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<TSTAT_SPEC>> for R {
+impl From<crate::R<TSTAT_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<TSTAT_SPEC>) -> Self {
         R(reader)
     }
@@ -27,119 +28,120 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<TSTAT_SPEC>> for W {
+impl From<crate::W<TSTAT_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<TSTAT_SPEC>) -> Self {
         W(writer)
     }
 }
-#[doc = "Transmit mailbox 2 last sending in transmit FIFO\n\nValue on reset: 0"]
+#[doc = "Transmit mailbox 2 last sending in transmit FIFO"]
+pub type TMLS2_A = TMLS0_A;
+#[doc = "Field `TMLS2` reader - Transmit mailbox 2 last sending in transmit FIFO"]
+pub type TMLS2_R = TMLS0_R;
+#[doc = "Transmit mailbox 1 last sending in transmit FIFO"]
+pub type TMLS1_A = TMLS0_A;
+#[doc = "Field `TMLS1` reader - Transmit mailbox 1 last sending in transmit FIFO"]
+pub type TMLS1_R = TMLS0_R;
+#[doc = "Transmit mailbox 0 last sending in transmit FIFO\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TMLS2_A {
+pub enum TMLS0_A {
     #[doc = "0: The mailbox doesn't have the last sending order"]
     NOTLAST = 0,
     #[doc = "1: The mailbox has the last sending order with at least two frames pending"]
     LAST = 1,
 }
-impl From<TMLS2_A> for bool {
+impl From<TMLS0_A> for bool {
     #[inline(always)]
-    fn from(variant: TMLS2_A) -> Self {
+    fn from(variant: TMLS0_A) -> Self {
         variant as u8 != 0
     }
 }
-#[doc = "Field `TMLS2` reader - Transmit mailbox 2 last sending in transmit FIFO"]
-pub struct TMLS2_R(crate::FieldReader<bool, TMLS2_A>);
-impl TMLS2_R {
+#[doc = "Field `TMLS0` reader - Transmit mailbox 0 last sending in transmit FIFO"]
+pub struct TMLS0_R(crate::FieldReader<bool, TMLS0_A>);
+impl TMLS0_R {
     pub(crate) fn new(bits: bool) -> Self {
-        TMLS2_R(crate::FieldReader::new(bits))
+        TMLS0_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> TMLS2_A {
+    pub fn variant(&self) -> TMLS0_A {
         match self.bits {
-            false => TMLS2_A::NOTLAST,
-            true => TMLS2_A::LAST,
+            false => TMLS0_A::NOTLAST,
+            true => TMLS0_A::LAST,
         }
     }
     #[doc = "Checks if the value of the field is `NOTLAST`"]
     #[inline(always)]
     pub fn is_not_last(&self) -> bool {
-        **self == TMLS2_A::NOTLAST
+        **self == TMLS0_A::NOTLAST
     }
     #[doc = "Checks if the value of the field is `LAST`"]
     #[inline(always)]
     pub fn is_last(&self) -> bool {
-        **self == TMLS2_A::LAST
+        **self == TMLS0_A::LAST
     }
 }
-impl core::ops::Deref for TMLS2_R {
-    type Target = crate::FieldReader<bool, TMLS2_A>;
+impl core::ops::Deref for TMLS0_R {
+    type Target = crate::FieldReader<bool, TMLS0_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Transmit mailbox 1 last sending in transmit FIFO"]
-pub type TMLS1_A = TMLS2_A;
-#[doc = "Field `TMLS1` reader - Transmit mailbox 1 last sending in transmit FIFO"]
-pub type TMLS1_R = TMLS2_R;
-#[doc = "Transmit mailbox 0 last sending in transmit FIFO"]
-pub type TMLS0_A = TMLS2_A;
-#[doc = "Field `TMLS0` reader - Transmit mailbox 0 last sending in transmit FIFO"]
-pub type TMLS0_R = TMLS2_R;
-#[doc = "Transmit mailbox 2 empty\n\nValue on reset: 1"]
+#[doc = "Transmit mailbox 2 empty"]
+pub type TME2_A = TME0_A;
+#[doc = "Field `TME2` reader - Transmit mailbox 2 empty"]
+pub type TME2_R = TME0_R;
+#[doc = "Transmit mailbox 1 empty"]
+pub type TME1_A = TME0_A;
+#[doc = "Field `TME1` reader - Transmit mailbox 1 empty"]
+pub type TME1_R = TME0_R;
+#[doc = "Transmit mailbox 0 empty\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub enum TME2_A {
+pub enum TME0_A {
     #[doc = "0: Transmit mailbox not empty"]
     NOTEMPTY = 0,
     #[doc = "1: Transmit mailbox is empty"]
     EMPTY = 1,
 }
-impl From<TME2_A> for bool {
+impl From<TME0_A> for bool {
     #[inline(always)]
-    fn from(variant: TME2_A) -> Self {
+    fn from(variant: TME0_A) -> Self {
         variant as u8 != 0
     }
 }
-#[doc = "Field `TME2` reader - Transmit mailbox 2 empty"]
-pub struct TME2_R(crate::FieldReader<bool, TME2_A>);
-impl TME2_R {
+#[doc = "Field `TME0` reader - Transmit mailbox 0 empty"]
+pub struct TME0_R(crate::FieldReader<bool, TME0_A>);
+impl TME0_R {
     pub(crate) fn new(bits: bool) -> Self {
-        TME2_R(crate::FieldReader::new(bits))
+        TME0_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> TME2_A {
+    pub fn variant(&self) -> TME0_A {
         match self.bits {
-            false => TME2_A::NOTEMPTY,
-            true => TME2_A::EMPTY,
+            false => TME0_A::NOTEMPTY,
+            true => TME0_A::EMPTY,
         }
     }
     #[doc = "Checks if the value of the field is `NOTEMPTY`"]
     #[inline(always)]
     pub fn is_not_empty(&self) -> bool {
-        **self == TME2_A::NOTEMPTY
+        **self == TME0_A::NOTEMPTY
     }
     #[doc = "Checks if the value of the field is `EMPTY`"]
     #[inline(always)]
     pub fn is_empty(&self) -> bool {
-        **self == TME2_A::EMPTY
+        **self == TME0_A::EMPTY
     }
 }
-impl core::ops::Deref for TME2_R {
-    type Target = crate::FieldReader<bool, TME2_A>;
+impl core::ops::Deref for TME0_R {
+    type Target = crate::FieldReader<bool, TME0_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Transmit mailbox 1 empty"]
-pub type TME1_A = TME2_A;
-#[doc = "Field `TME1` reader - Transmit mailbox 1 empty"]
-pub type TME1_R = TME2_R;
-#[doc = "Transmit mailbox 0 empty"]
-pub type TME0_A = TME2_A;
-#[doc = "Field `TME0` reader - Transmit mailbox 0 empty"]
-pub type TME0_R = TME2_R;
 #[doc = "Field `NUM` reader - number of the transmit FIFO mailbox in which the frame will be transmitted if at least one mailbox is empty"]
 pub struct NUM_R(crate::FieldReader<u8, u8>);
 impl NUM_R {
@@ -154,64 +156,12 @@ impl core::ops::Deref for NUM_R {
         &self.0
     }
 }
-#[doc = "Mailbox 2 stop transmitting\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MST2_A {
-    #[doc = "0: Mailbox is not stopped, or is empty"]
-    NOTSTOP = 0,
-    #[doc = "1: Stop mailbox transmitting"]
-    STOP = 1,
-}
-impl From<MST2_A> for bool {
-    #[inline(always)]
-    fn from(variant: MST2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Mailbox 2 stop transmitting"]
+pub type MST2_A = MST0_A;
 #[doc = "Field `MST2` reader - Mailbox 2 stop transmitting"]
-pub struct MST2_R(crate::FieldReader<bool, MST2_A>);
-impl MST2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MST2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MST2_A {
-        match self.bits {
-            false => MST2_A::NOTSTOP,
-            true => MST2_A::STOP,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOTSTOP`"]
-    #[inline(always)]
-    pub fn is_not_stop(&self) -> bool {
-        **self == MST2_A::NOTSTOP
-    }
-    #[doc = "Checks if the value of the field is `STOP`"]
-    #[inline(always)]
-    pub fn is_stop(&self) -> bool {
-        **self == MST2_A::STOP
-    }
-}
-impl core::ops::Deref for MST2_R {
-    type Target = crate::FieldReader<bool, MST2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Mailbox 2 stop transmitting\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MST2_AW {
-    #[doc = "1: Stop mailbox transmitting"]
-    STOP = 1,
-}
-impl From<MST2_AW> for bool {
-    #[inline(always)]
-    fn from(variant: MST2_AW) -> Self {
-        variant as u8 != 0
-    }
-}
+pub type MST2_R = MST0_R;
+#[doc = "Mailbox 2 stop transmitting"]
+pub type MST2_AW = MST0_AW;
 #[doc = "Field `MST2` writer - Mailbox 2 stop transmitting"]
 pub struct MST2_W<'a> {
     w: &'a mut W,
@@ -244,64 +194,12 @@ impl<'a> MST2_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 2 transmit error\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTE2_A {
-    #[doc = "0: There was no error"]
-    NOERROR = 0,
-    #[doc = "1: An error was detected"]
-    ERROR = 1,
-}
-impl From<MTE2_A> for bool {
-    #[inline(always)]
-    fn from(variant: MTE2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Mailbox 2 transmit error"]
+pub type MTE2_A = MTE0_A;
 #[doc = "Field `MTE2` reader - Mailbox 2 transmit error"]
-pub struct MTE2_R(crate::FieldReader<bool, MTE2_A>);
-impl MTE2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MTE2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MTE2_A {
-        match self.bits {
-            false => MTE2_A::NOERROR,
-            true => MTE2_A::ERROR,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOERROR`"]
-    #[inline(always)]
-    pub fn is_no_error(&self) -> bool {
-        **self == MTE2_A::NOERROR
-    }
-    #[doc = "Checks if the value of the field is `ERROR`"]
-    #[inline(always)]
-    pub fn is_error(&self) -> bool {
-        **self == MTE2_A::ERROR
-    }
-}
-impl core::ops::Deref for MTE2_R {
-    type Target = crate::FieldReader<bool, MTE2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Mailbox 2 transmit error\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTE2_AW {
-    #[doc = "1: Clears error flag"]
-    CLEAR = 1,
-}
-impl From<MTE2_AW> for bool {
-    #[inline(always)]
-    fn from(variant: MTE2_AW) -> Self {
-        variant as u8 != 0
-    }
-}
+pub type MTE2_R = MTE0_R;
+#[doc = "Mailbox 2 transmit error"]
+pub type MTE2_AW = MTE0_AW;
 #[doc = "Field `MTE2` writer - Mailbox 2 transmit error"]
 pub struct MTE2_W<'a> {
     w: &'a mut W,
@@ -334,64 +232,12 @@ impl<'a> MTE2_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 2 arbitration lost\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MAL2_A {
-    #[doc = "0: Arbitration was not lost"]
-    NOARBITRATIONLOST = 0,
-    #[doc = "1: Arbitration lost"]
-    ARBITRATIONLOST = 1,
-}
-impl From<MAL2_A> for bool {
-    #[inline(always)]
-    fn from(variant: MAL2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Mailbox 2 arbitration lost"]
+pub type MAL2_A = MAL0_A;
 #[doc = "Field `MAL2` reader - Mailbox 2 arbitration lost"]
-pub struct MAL2_R(crate::FieldReader<bool, MAL2_A>);
-impl MAL2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MAL2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MAL2_A {
-        match self.bits {
-            false => MAL2_A::NOARBITRATIONLOST,
-            true => MAL2_A::ARBITRATIONLOST,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOARBITRATIONLOST`"]
-    #[inline(always)]
-    pub fn is_no_arbitration_lost(&self) -> bool {
-        **self == MAL2_A::NOARBITRATIONLOST
-    }
-    #[doc = "Checks if the value of the field is `ARBITRATIONLOST`"]
-    #[inline(always)]
-    pub fn is_arbitration_lost(&self) -> bool {
-        **self == MAL2_A::ARBITRATIONLOST
-    }
-}
-impl core::ops::Deref for MAL2_R {
-    type Target = crate::FieldReader<bool, MAL2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Mailbox 2 arbitration lost\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MAL2_AW {
-    #[doc = "1: Clears flag"]
-    CLEAR = 1,
-}
-impl From<MAL2_AW> for bool {
-    #[inline(always)]
-    fn from(variant: MAL2_AW) -> Self {
-        variant as u8 != 0
-    }
-}
+pub type MAL2_R = MAL0_R;
+#[doc = "Mailbox 2 arbitration lost"]
+pub type MAL2_AW = MAL0_AW;
 #[doc = "Field `MAL2` writer - Mailbox 2 arbitration lost"]
 pub struct MAL2_W<'a> {
     w: &'a mut W,
@@ -424,64 +270,12 @@ impl<'a> MAL2_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 2 transmit finished and no error\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTFNERR2_A {
-    #[doc = "0: Mailbox transmission finished with an error"]
-    FINISHEDWITHERROR = 0,
-    #[doc = "1: Mailbox transmission finished with no error"]
-    FINISHEDNOERROR = 1,
-}
-impl From<MTFNERR2_A> for bool {
-    #[inline(always)]
-    fn from(variant: MTFNERR2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Mailbox 2 transmit finished and no error"]
+pub type MTFNERR2_A = MTFNERR0_A;
 #[doc = "Field `MTFNERR2` reader - Mailbox 2 transmit finished and no error"]
-pub struct MTFNERR2_R(crate::FieldReader<bool, MTFNERR2_A>);
-impl MTFNERR2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MTFNERR2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MTFNERR2_A {
-        match self.bits {
-            false => MTFNERR2_A::FINISHEDWITHERROR,
-            true => MTFNERR2_A::FINISHEDNOERROR,
-        }
-    }
-    #[doc = "Checks if the value of the field is `FINISHEDWITHERROR`"]
-    #[inline(always)]
-    pub fn is_finished_with_error(&self) -> bool {
-        **self == MTFNERR2_A::FINISHEDWITHERROR
-    }
-    #[doc = "Checks if the value of the field is `FINISHEDNOERROR`"]
-    #[inline(always)]
-    pub fn is_finished_no_error(&self) -> bool {
-        **self == MTFNERR2_A::FINISHEDNOERROR
-    }
-}
-impl core::ops::Deref for MTFNERR2_R {
-    type Target = crate::FieldReader<bool, MTFNERR2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Mailbox 2 transmit finished and no error\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTFNERR2_AW {
-    #[doc = "1: Clears flag"]
-    CLEAR = 1,
-}
-impl From<MTFNERR2_AW> for bool {
-    #[inline(always)]
-    fn from(variant: MTFNERR2_AW) -> Self {
-        variant as u8 != 0
-    }
-}
+pub type MTFNERR2_R = MTFNERR0_R;
+#[doc = "Mailbox 2 transmit finished and no error"]
+pub type MTFNERR2_AW = MTFNERR0_AW;
 #[doc = "Field `MTFNERR2` writer - Mailbox 2 transmit finished and no error"]
 pub struct MTFNERR2_W<'a> {
     w: &'a mut W,
@@ -514,64 +308,12 @@ impl<'a> MTFNERR2_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 2 transmit finished\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTF2_A {
-    #[doc = "0: Mailbox transmission still in progress"]
-    INPROGRESS = 0,
-    #[doc = "1: Mailbox transmission finished"]
-    FINISHED = 1,
-}
-impl From<MTF2_A> for bool {
-    #[inline(always)]
-    fn from(variant: MTF2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Mailbox 2 transmit finished"]
+pub type MTF2_A = MTF0_A;
 #[doc = "Field `MTF2` reader - Mailbox 2 transmit finished"]
-pub struct MTF2_R(crate::FieldReader<bool, MTF2_A>);
-impl MTF2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MTF2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MTF2_A {
-        match self.bits {
-            false => MTF2_A::INPROGRESS,
-            true => MTF2_A::FINISHED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `INPROGRESS`"]
-    #[inline(always)]
-    pub fn is_in_progress(&self) -> bool {
-        **self == MTF2_A::INPROGRESS
-    }
-    #[doc = "Checks if the value of the field is `FINISHED`"]
-    #[inline(always)]
-    pub fn is_finished(&self) -> bool {
-        **self == MTF2_A::FINISHED
-    }
-}
-impl core::ops::Deref for MTF2_R {
-    type Target = crate::FieldReader<bool, MTF2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Mailbox 2 transmit finished\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTF2_AW {
-    #[doc = "1: Clears flag"]
-    CLEAR = 1,
-}
-impl From<MTF2_AW> for bool {
-    #[inline(always)]
-    fn from(variant: MTF2_AW) -> Self {
-        variant as u8 != 0
-    }
-}
+pub type MTF2_R = MTF0_R;
+#[doc = "Mailbox 2 transmit finished"]
+pub type MTF2_AW = MTF0_AW;
 #[doc = "Field `MTF2` writer - Mailbox 2 transmit finished"]
 pub struct MTF2_W<'a> {
     w: &'a mut W,
@@ -605,11 +347,11 @@ impl<'a> MTF2_W<'a> {
     }
 }
 #[doc = "Mailbox 1 stop transmitting"]
-pub type MST1_A = MST2_A;
+pub type MST1_A = MST0_A;
 #[doc = "Field `MST1` reader - Mailbox 1 stop transmitting"]
-pub type MST1_R = MST2_R;
+pub type MST1_R = MST0_R;
 #[doc = "Mailbox 1 stop transmitting"]
-pub type MST1_AW = MST2_AW;
+pub type MST1_AW = MST0_AW;
 #[doc = "Field `MST1` writer - Mailbox 1 stop transmitting"]
 pub struct MST1_W<'a> {
     w: &'a mut W,
@@ -643,11 +385,11 @@ impl<'a> MST1_W<'a> {
     }
 }
 #[doc = "Mailbox 1 transmit error"]
-pub type MTE1_A = MTE2_A;
+pub type MTE1_A = MTE0_A;
 #[doc = "Field `MTE1` reader - Mailbox 1 transmit error"]
-pub type MTE1_R = MTE2_R;
+pub type MTE1_R = MTE0_R;
 #[doc = "Mailbox 1 transmit error"]
-pub type MTE1_AW = MTE2_AW;
+pub type MTE1_AW = MTE0_AW;
 #[doc = "Field `MTE1` writer - Mailbox 1 transmit error"]
 pub struct MTE1_W<'a> {
     w: &'a mut W,
@@ -681,11 +423,11 @@ impl<'a> MTE1_W<'a> {
     }
 }
 #[doc = "Mailbox 1 arbitration lost"]
-pub type MAL1_A = MAL2_A;
+pub type MAL1_A = MAL0_A;
 #[doc = "Field `MAL1` reader - Mailbox 1 arbitration lost"]
-pub type MAL1_R = MAL2_R;
+pub type MAL1_R = MAL0_R;
 #[doc = "Mailbox 1 arbitration lost"]
-pub type MAL1_AW = MAL2_AW;
+pub type MAL1_AW = MAL0_AW;
 #[doc = "Field `MAL1` writer - Mailbox 1 arbitration lost"]
 pub struct MAL1_W<'a> {
     w: &'a mut W,
@@ -719,11 +461,11 @@ impl<'a> MAL1_W<'a> {
     }
 }
 #[doc = "Mailbox 1 transmit finished and no error"]
-pub type MTFNERR1_A = MTFNERR2_A;
+pub type MTFNERR1_A = MTFNERR0_A;
 #[doc = "Field `MTFNERR1` reader - Mailbox 1 transmit finished and no error"]
-pub type MTFNERR1_R = MTFNERR2_R;
+pub type MTFNERR1_R = MTFNERR0_R;
 #[doc = "Mailbox 1 transmit finished and no error"]
-pub type MTFNERR1_AW = MTFNERR2_AW;
+pub type MTFNERR1_AW = MTFNERR0_AW;
 #[doc = "Field `MTFNERR1` writer - Mailbox 1 transmit finished and no error"]
 pub struct MTFNERR1_W<'a> {
     w: &'a mut W,
@@ -757,11 +499,11 @@ impl<'a> MTFNERR1_W<'a> {
     }
 }
 #[doc = "Mailbox 1 transmit finished"]
-pub type MTF1_A = MTF2_A;
+pub type MTF1_A = MTF0_A;
 #[doc = "Field `MTF1` reader - Mailbox 1 transmit finished"]
-pub type MTF1_R = MTF2_R;
+pub type MTF1_R = MTF0_R;
 #[doc = "Mailbox 1 transmit finished"]
-pub type MTF1_AW = MTF2_AW;
+pub type MTF1_AW = MTF0_AW;
 #[doc = "Field `MTF1` writer - Mailbox 1 transmit finished"]
 pub struct MTF1_W<'a> {
     w: &'a mut W,
@@ -794,12 +536,64 @@ impl<'a> MTF1_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 0 stop transmitting"]
-pub type MST0_A = MST2_A;
+#[doc = "Mailbox 0 stop transmitting\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MST0_A {
+    #[doc = "0: Mailbox is not stopped, or is empty"]
+    NOTSTOP = 0,
+    #[doc = "1: Stop mailbox transmitting"]
+    STOP = 1,
+}
+impl From<MST0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MST0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MST0` reader - Mailbox 0 stop transmitting"]
-pub type MST0_R = MST2_R;
-#[doc = "Mailbox 0 stop transmitting"]
-pub type MST0_AW = MST2_AW;
+pub struct MST0_R(crate::FieldReader<bool, MST0_A>);
+impl MST0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MST0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MST0_A {
+        match self.bits {
+            false => MST0_A::NOTSTOP,
+            true => MST0_A::STOP,
+        }
+    }
+    #[doc = "Checks if the value of the field is `NOTSTOP`"]
+    #[inline(always)]
+    pub fn is_not_stop(&self) -> bool {
+        **self == MST0_A::NOTSTOP
+    }
+    #[doc = "Checks if the value of the field is `STOP`"]
+    #[inline(always)]
+    pub fn is_stop(&self) -> bool {
+        **self == MST0_A::STOP
+    }
+}
+impl core::ops::Deref for MST0_R {
+    type Target = crate::FieldReader<bool, MST0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Mailbox 0 stop transmitting\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MST0_AW {
+    #[doc = "1: Stop mailbox transmitting"]
+    STOP = 1,
+}
+impl From<MST0_AW> for bool {
+    #[inline(always)]
+    fn from(variant: MST0_AW) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MST0` writer - Mailbox 0 stop transmitting"]
 pub struct MST0_W<'a> {
     w: &'a mut W,
@@ -832,12 +626,64 @@ impl<'a> MST0_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 0 transmit error"]
-pub type MTE0_A = MTE2_A;
+#[doc = "Mailbox 0 transmit error\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTE0_A {
+    #[doc = "0: There was no error"]
+    NOERROR = 0,
+    #[doc = "1: An error was detected"]
+    ERROR = 1,
+}
+impl From<MTE0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTE0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTE0` reader - Mailbox 0 transmit error"]
-pub type MTE0_R = MTE2_R;
-#[doc = "Mailbox 0 transmit error"]
-pub type MTE0_AW = MTE2_AW;
+pub struct MTE0_R(crate::FieldReader<bool, MTE0_A>);
+impl MTE0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTE0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTE0_A {
+        match self.bits {
+            false => MTE0_A::NOERROR,
+            true => MTE0_A::ERROR,
+        }
+    }
+    #[doc = "Checks if the value of the field is `NOERROR`"]
+    #[inline(always)]
+    pub fn is_no_error(&self) -> bool {
+        **self == MTE0_A::NOERROR
+    }
+    #[doc = "Checks if the value of the field is `ERROR`"]
+    #[inline(always)]
+    pub fn is_error(&self) -> bool {
+        **self == MTE0_A::ERROR
+    }
+}
+impl core::ops::Deref for MTE0_R {
+    type Target = crate::FieldReader<bool, MTE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Mailbox 0 transmit error\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTE0_AW {
+    #[doc = "1: Clears error flag"]
+    CLEAR = 1,
+}
+impl From<MTE0_AW> for bool {
+    #[inline(always)]
+    fn from(variant: MTE0_AW) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTE0` writer - Mailbox 0 transmit error"]
 pub struct MTE0_W<'a> {
     w: &'a mut W,
@@ -870,12 +716,64 @@ impl<'a> MTE0_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 0 arbitration lost"]
-pub type MAL0_A = MAL2_A;
+#[doc = "Mailbox 0 arbitration lost\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MAL0_A {
+    #[doc = "0: Arbitration was not lost"]
+    NOARBITRATIONLOST = 0,
+    #[doc = "1: Arbitration lost"]
+    ARBITRATIONLOST = 1,
+}
+impl From<MAL0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MAL0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MAL0` reader - Mailbox 0 arbitration lost"]
-pub type MAL0_R = MAL2_R;
-#[doc = "Mailbox 0 arbitration lost"]
-pub type MAL0_AW = MAL2_AW;
+pub struct MAL0_R(crate::FieldReader<bool, MAL0_A>);
+impl MAL0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MAL0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MAL0_A {
+        match self.bits {
+            false => MAL0_A::NOARBITRATIONLOST,
+            true => MAL0_A::ARBITRATIONLOST,
+        }
+    }
+    #[doc = "Checks if the value of the field is `NOARBITRATIONLOST`"]
+    #[inline(always)]
+    pub fn is_no_arbitration_lost(&self) -> bool {
+        **self == MAL0_A::NOARBITRATIONLOST
+    }
+    #[doc = "Checks if the value of the field is `ARBITRATIONLOST`"]
+    #[inline(always)]
+    pub fn is_arbitration_lost(&self) -> bool {
+        **self == MAL0_A::ARBITRATIONLOST
+    }
+}
+impl core::ops::Deref for MAL0_R {
+    type Target = crate::FieldReader<bool, MAL0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Mailbox 0 arbitration lost\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MAL0_AW {
+    #[doc = "1: Clears flag"]
+    CLEAR = 1,
+}
+impl From<MAL0_AW> for bool {
+    #[inline(always)]
+    fn from(variant: MAL0_AW) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MAL0` writer - Mailbox 0 arbitration lost"]
 pub struct MAL0_W<'a> {
     w: &'a mut W,
@@ -908,12 +806,64 @@ impl<'a> MAL0_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 0 transmit finished and no error"]
-pub type MTFNERR0_A = MTFNERR2_A;
+#[doc = "Mailbox 0 transmit finished and no error\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTFNERR0_A {
+    #[doc = "0: Mailbox transmission finished with an error"]
+    FINISHEDWITHERROR = 0,
+    #[doc = "1: Mailbox transmission finished with no error"]
+    FINISHEDNOERROR = 1,
+}
+impl From<MTFNERR0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTFNERR0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTFNERR0` reader - Mailbox 0 transmit finished and no error"]
-pub type MTFNERR0_R = MTFNERR2_R;
-#[doc = "Mailbox 0 transmit finished and no error"]
-pub type MTFNERR0_AW = MTFNERR2_AW;
+pub struct MTFNERR0_R(crate::FieldReader<bool, MTFNERR0_A>);
+impl MTFNERR0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTFNERR0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTFNERR0_A {
+        match self.bits {
+            false => MTFNERR0_A::FINISHEDWITHERROR,
+            true => MTFNERR0_A::FINISHEDNOERROR,
+        }
+    }
+    #[doc = "Checks if the value of the field is `FINISHEDWITHERROR`"]
+    #[inline(always)]
+    pub fn is_finished_with_error(&self) -> bool {
+        **self == MTFNERR0_A::FINISHEDWITHERROR
+    }
+    #[doc = "Checks if the value of the field is `FINISHEDNOERROR`"]
+    #[inline(always)]
+    pub fn is_finished_no_error(&self) -> bool {
+        **self == MTFNERR0_A::FINISHEDNOERROR
+    }
+}
+impl core::ops::Deref for MTFNERR0_R {
+    type Target = crate::FieldReader<bool, MTFNERR0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Mailbox 0 transmit finished and no error\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTFNERR0_AW {
+    #[doc = "1: Clears flag"]
+    CLEAR = 1,
+}
+impl From<MTFNERR0_AW> for bool {
+    #[inline(always)]
+    fn from(variant: MTFNERR0_AW) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTFNERR0` writer - Mailbox 0 transmit finished and no error"]
 pub struct MTFNERR0_W<'a> {
     w: &'a mut W,
@@ -946,12 +896,64 @@ impl<'a> MTFNERR0_W<'a> {
         self.w
     }
 }
-#[doc = "Mailbox 0 transmit finished"]
-pub type MTF0_A = MTF2_A;
+#[doc = "Mailbox 0 transmit finished\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTF0_A {
+    #[doc = "0: Mailbox transmission still in progress"]
+    INPROGRESS = 0,
+    #[doc = "1: Mailbox transmission finished"]
+    FINISHED = 1,
+}
+impl From<MTF0_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTF0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTF0` reader - Mailbox 0 transmit finished"]
-pub type MTF0_R = MTF2_R;
-#[doc = "Mailbox 0 transmit finished"]
-pub type MTF0_AW = MTF2_AW;
+pub struct MTF0_R(crate::FieldReader<bool, MTF0_A>);
+impl MTF0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTF0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTF0_A {
+        match self.bits {
+            false => MTF0_A::INPROGRESS,
+            true => MTF0_A::FINISHED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `INPROGRESS`"]
+    #[inline(always)]
+    pub fn is_in_progress(&self) -> bool {
+        **self == MTF0_A::INPROGRESS
+    }
+    #[doc = "Checks if the value of the field is `FINISHED`"]
+    #[inline(always)]
+    pub fn is_finished(&self) -> bool {
+        **self == MTF0_A::FINISHED
+    }
+}
+impl core::ops::Deref for MTF0_R {
+    type Target = crate::FieldReader<bool, MTF0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Mailbox 0 transmit finished\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTF0_AW {
+    #[doc = "1: Clears flag"]
+    CLEAR = 1,
+}
+impl From<MTF0_AW> for bool {
+    #[inline(always)]
+    fn from(variant: MTF0_AW) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `MTF0` writer - Mailbox 0 transmit finished"]
 pub struct MTF0_W<'a> {
     w: &'a mut W,
@@ -1173,6 +1175,7 @@ impl W {
         MTF0_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
