@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<CHCTL1_INPUT_SPEC>> for R {
+impl From<crate::R<CHCTL1_INPUT_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<CHCTL1_INPUT_SPEC>) -> Self {
         R(reader)
     }
@@ -27,171 +28,16 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<CHCTL1_INPUT_SPEC>> for W {
+impl From<crate::W<CHCTL1_INPUT_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<CHCTL1_INPUT_SPEC>) -> Self {
         W(writer)
     }
 }
-#[doc = "Channel 3 input capture filter control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH3CAPFLT_A {
-    #[doc = "0: Filter disabled. fSAMP=fDTS, N=1"]
-    NOFILTER = 0,
-    #[doc = "1: fSAMP=fTIMER_CK, N=2"]
-    TIMERCK_N2 = 1,
-    #[doc = "2: fSAMP=fTIMER_CK, N=4"]
-    TIMERCK_N4 = 2,
-    #[doc = "3: fSAMP=fTIMER_CK, N=8"]
-    TIMERCK_N8 = 3,
-    #[doc = "4: fSAMP=fDTS/2, N=6"]
-    FDTS_DIV2_N6 = 4,
-    #[doc = "5: fSAMP=fDTS/2, N=8"]
-    FDTS_DIV2_N8 = 5,
-    #[doc = "6: fSAMP=fDTS/4, N=6"]
-    FDTS_DIV4_N6 = 6,
-    #[doc = "7: fSAMP=fDTS/4, N=8"]
-    FDTS_DIV4_N8 = 7,
-    #[doc = "8: fSAMP=fDTS/8, N=6"]
-    FDTS_DIV8_N6 = 8,
-    #[doc = "9: fSAMP=fDTS/8, N=8"]
-    FDTS_DIV8_N8 = 9,
-    #[doc = "10: fSAMP=fDTS/16, N=5"]
-    FDTS_DIV16_N5 = 10,
-    #[doc = "11: fSAMP=fDTS/16, N=6"]
-    FDTS_DIV16_N6 = 11,
-    #[doc = "12: fSAMP=fDTS/16, N=8"]
-    FDTS_DIV16_N8 = 12,
-    #[doc = "13: fSAMP=fDTS/32, N=5"]
-    FDTS_DIV32_N5 = 13,
-    #[doc = "14: fSAMP=fDTS/32, N=6"]
-    FDTS_DIV32_N6 = 14,
-    #[doc = "15: fSAMP=fDTS/32, N=8"]
-    FDTS_DIV32_N8 = 15,
-}
-impl From<CH3CAPFLT_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH3CAPFLT_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 3 input capture filter control"]
+pub type CH3CAPFLT_A = super::chctl0_input::CH0CAPFLT_A;
 #[doc = "Field `CH3CAPFLT` reader - Channel 3 input capture filter control"]
-pub struct CH3CAPFLT_R(crate::FieldReader<u8, CH3CAPFLT_A>);
-impl CH3CAPFLT_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH3CAPFLT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3CAPFLT_A {
-        match self.bits {
-            0 => CH3CAPFLT_A::NOFILTER,
-            1 => CH3CAPFLT_A::TIMERCK_N2,
-            2 => CH3CAPFLT_A::TIMERCK_N4,
-            3 => CH3CAPFLT_A::TIMERCK_N8,
-            4 => CH3CAPFLT_A::FDTS_DIV2_N6,
-            5 => CH3CAPFLT_A::FDTS_DIV2_N8,
-            6 => CH3CAPFLT_A::FDTS_DIV4_N6,
-            7 => CH3CAPFLT_A::FDTS_DIV4_N8,
-            8 => CH3CAPFLT_A::FDTS_DIV8_N6,
-            9 => CH3CAPFLT_A::FDTS_DIV8_N8,
-            10 => CH3CAPFLT_A::FDTS_DIV16_N5,
-            11 => CH3CAPFLT_A::FDTS_DIV16_N6,
-            12 => CH3CAPFLT_A::FDTS_DIV16_N8,
-            13 => CH3CAPFLT_A::FDTS_DIV32_N5,
-            14 => CH3CAPFLT_A::FDTS_DIV32_N6,
-            15 => CH3CAPFLT_A::FDTS_DIV32_N8,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOFILTER`"]
-    #[inline(always)]
-    pub fn is_no_filter(&self) -> bool {
-        **self == CH3CAPFLT_A::NOFILTER
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N2`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n2(&self) -> bool {
-        **self == CH3CAPFLT_A::TIMERCK_N2
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N4`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n4(&self) -> bool {
-        **self == CH3CAPFLT_A::TIMERCK_N4
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N8`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::TIMERCK_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV2_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div2_n6(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV2_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV2_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div2_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV2_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV4_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div4_n6(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV4_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV4_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div4_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV4_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV8_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div8_n6(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV8_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV8_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div8_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV8_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N5`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n5(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV16_N5
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n6(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV16_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV16_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N5`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n5(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV32_N5
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n6(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV32_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n8(&self) -> bool {
-        **self == CH3CAPFLT_A::FDTS_DIV32_N8
-    }
-}
-impl core::ops::Deref for CH3CAPFLT_R {
-    type Target = crate::FieldReader<u8, CH3CAPFLT_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3CAPFLT_R = super::chctl0_input::CH0CAPFLT_R;
 #[doc = "Field `CH3CAPFLT` writer - Channel 3 input capture filter control"]
 pub struct CH3CAPFLT_W<'a> {
     w: &'a mut W,
@@ -289,70 +135,10 @@ impl<'a> CH3CAPFLT_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 input capture prescaler\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH3CAPPSC_A {
-    #[doc = "0: Prescaler disabled, capture on every edge"]
-    DIV1 = 0,
-    #[doc = "1: Capture every 2 edges"]
-    DIV2 = 1,
-    #[doc = "2: Capture every 4 edges"]
-    DIV4 = 2,
-    #[doc = "3: Capture every 8 edges"]
-    DIV8 = 3,
-}
-impl From<CH3CAPPSC_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH3CAPPSC_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 3 input capture prescaler"]
+pub type CH3CAPPSC_A = super::chctl0_input::CH0CAPPSC_A;
 #[doc = "Field `CH3CAPPSC` reader - Channel 3 input capture prescaler"]
-pub struct CH3CAPPSC_R(crate::FieldReader<u8, CH3CAPPSC_A>);
-impl CH3CAPPSC_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH3CAPPSC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3CAPPSC_A {
-        match self.bits {
-            0 => CH3CAPPSC_A::DIV1,
-            1 => CH3CAPPSC_A::DIV2,
-            2 => CH3CAPPSC_A::DIV4,
-            3 => CH3CAPPSC_A::DIV8,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `DIV1`"]
-    #[inline(always)]
-    pub fn is_div1(&self) -> bool {
-        **self == CH3CAPPSC_A::DIV1
-    }
-    #[doc = "Checks if the value of the field is `DIV2`"]
-    #[inline(always)]
-    pub fn is_div2(&self) -> bool {
-        **self == CH3CAPPSC_A::DIV2
-    }
-    #[doc = "Checks if the value of the field is `DIV4`"]
-    #[inline(always)]
-    pub fn is_div4(&self) -> bool {
-        **self == CH3CAPPSC_A::DIV4
-    }
-    #[doc = "Checks if the value of the field is `DIV8`"]
-    #[inline(always)]
-    pub fn is_div8(&self) -> bool {
-        **self == CH3CAPPSC_A::DIV8
-    }
-}
-impl core::ops::Deref for CH3CAPPSC_R {
-    type Target = crate::FieldReader<u8, CH3CAPPSC_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3CAPPSC_R = super::chctl0_input::CH0CAPPSC_R;
 #[doc = "Field `CH3CAPPSC` writer - Channel 3 input capture prescaler"]
 pub struct CH3CAPPSC_W<'a> {
     w: &'a mut W,
@@ -390,70 +176,10 @@ impl<'a> CH3CAPPSC_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 mode selection\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH3MS_A {
-    #[doc = "0: Channel is configured as output"]
-    OUTPUT = 0,
-    #[doc = "1: Channel is configured as input, ISx is connected to CI0FEx"]
-    CI0 = 1,
-    #[doc = "2: Channel is configured as input, ISx is connected to CI1FEx"]
-    CI1 = 2,
-    #[doc = "3: Channel is configured as input, ISx is connected to ITS"]
-    ITS = 3,
-}
-impl From<CH3MS_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH3MS_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 3 mode selection"]
+pub type CH3MS_A = super::chctl0_input::CH0MS_A;
 #[doc = "Field `CH3MS` reader - Channel 3 mode selection"]
-pub struct CH3MS_R(crate::FieldReader<u8, CH3MS_A>);
-impl CH3MS_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH3MS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3MS_A {
-        match self.bits {
-            0 => CH3MS_A::OUTPUT,
-            1 => CH3MS_A::CI0,
-            2 => CH3MS_A::CI1,
-            3 => CH3MS_A::ITS,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `OUTPUT`"]
-    #[inline(always)]
-    pub fn is_output(&self) -> bool {
-        **self == CH3MS_A::OUTPUT
-    }
-    #[doc = "Checks if the value of the field is `CI0`"]
-    #[inline(always)]
-    pub fn is_ci0(&self) -> bool {
-        **self == CH3MS_A::CI0
-    }
-    #[doc = "Checks if the value of the field is `CI1`"]
-    #[inline(always)]
-    pub fn is_ci1(&self) -> bool {
-        **self == CH3MS_A::CI1
-    }
-    #[doc = "Checks if the value of the field is `ITS`"]
-    #[inline(always)]
-    pub fn is_its(&self) -> bool {
-        **self == CH3MS_A::ITS
-    }
-}
-impl core::ops::Deref for CH3MS_R {
-    type Target = crate::FieldReader<u8, CH3MS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3MS_R = super::chctl0_input::CH0MS_R;
 #[doc = "Field `CH3MS` writer - Channel 3 mode selection"]
 pub struct CH3MS_W<'a> {
     w: &'a mut W,
@@ -492,9 +218,9 @@ impl<'a> CH3MS_W<'a> {
     }
 }
 #[doc = "Channel 2 input capture filter control"]
-pub type CH2CAPFLT_A = CH3CAPFLT_A;
+pub type CH2CAPFLT_A = super::chctl0_input::CH0CAPFLT_A;
 #[doc = "Field `CH2CAPFLT` reader - Channel 2 input capture filter control"]
-pub type CH2CAPFLT_R = CH3CAPFLT_R;
+pub type CH2CAPFLT_R = super::chctl0_input::CH0CAPFLT_R;
 #[doc = "Field `CH2CAPFLT` writer - Channel 2 input capture filter control"]
 pub struct CH2CAPFLT_W<'a> {
     w: &'a mut W,
@@ -593,9 +319,9 @@ impl<'a> CH2CAPFLT_W<'a> {
     }
 }
 #[doc = "Channel 2 input capture prescaler"]
-pub type CH2CAPPSC_A = CH3CAPPSC_A;
+pub type CH2CAPPSC_A = super::chctl0_input::CH0CAPPSC_A;
 #[doc = "Field `CH2CAPPSC` reader - Channel 2 input capture prescaler"]
-pub type CH2CAPPSC_R = CH3CAPPSC_R;
+pub type CH2CAPPSC_R = super::chctl0_input::CH0CAPPSC_R;
 #[doc = "Field `CH2CAPPSC` writer - Channel 2 input capture prescaler"]
 pub struct CH2CAPPSC_W<'a> {
     w: &'a mut W,
@@ -634,9 +360,9 @@ impl<'a> CH2CAPPSC_W<'a> {
     }
 }
 #[doc = "Channel 2 mode selection"]
-pub type CH2MS_A = CH3MS_A;
+pub type CH2MS_A = super::chctl0_input::CH0MS_A;
 #[doc = "Field `CH2MS` reader - Channel 2 mode selection"]
-pub type CH2MS_R = CH3MS_R;
+pub type CH2MS_R = super::chctl0_input::CH0MS_R;
 #[doc = "Field `CH2MS` writer - Channel 2 mode selection"]
 pub struct CH2MS_W<'a> {
     w: &'a mut W,
@@ -738,6 +464,7 @@ impl W {
         CH2MS_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
         self.0.bits(bits);
         self
