@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<INTEN_SPEC>> for R {
+impl From<crate::R<INTEN_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<INTEN_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<INTEN_SPEC>> for W {
+impl From<crate::W<INTEN_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<INTEN_SPEC>) -> Self {
         W(writer)
     }
@@ -613,52 +615,10 @@ impl<'a> WERRIE_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO1 overfull interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum RFOIE1_A {
-    #[doc = "0: Receive FIFO overfull interrupt is disabled"]
-    DISABLED = 0,
-    #[doc = "1: Receive FIFO overfull interrupt is enabled"]
-    ENABLED = 1,
-}
-impl From<RFOIE1_A> for bool {
-    #[inline(always)]
-    fn from(variant: RFOIE1_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Receive FIFO1 overfull interrupt enable"]
+pub type RFOIE1_A = RFOIE0_A;
 #[doc = "Field `RFOIE1` reader - Receive FIFO1 overfull interrupt enable"]
-pub struct RFOIE1_R(crate::FieldReader<bool, RFOIE1_A>);
-impl RFOIE1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        RFOIE1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> RFOIE1_A {
-        match self.bits {
-            false => RFOIE1_A::DISABLED,
-            true => RFOIE1_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == RFOIE1_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == RFOIE1_A::ENABLED
-    }
-}
-impl core::ops::Deref for RFOIE1_R {
-    type Target = crate::FieldReader<bool, RFOIE1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RFOIE1_R = RFOIE0_R;
 #[doc = "Field `RFOIE1` writer - Receive FIFO1 overfull interrupt enable"]
 pub struct RFOIE1_W<'a> {
     w: &'a mut W,
@@ -696,52 +656,10 @@ impl<'a> RFOIE1_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO1 full interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum RFFIE1_A {
-    #[doc = "0: Receive FIFO full interrupt is disabled"]
-    DISABLED = 0,
-    #[doc = "1: Receive FIFO full interrupt is enabled"]
-    ENABLED = 1,
-}
-impl From<RFFIE1_A> for bool {
-    #[inline(always)]
-    fn from(variant: RFFIE1_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Receive FIFO1 full interrupt enable"]
+pub type RFFIE1_A = RFFIE0_A;
 #[doc = "Field `RFFIE1` reader - Receive FIFO1 full interrupt enable"]
-pub struct RFFIE1_R(crate::FieldReader<bool, RFFIE1_A>);
-impl RFFIE1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        RFFIE1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> RFFIE1_A {
-        match self.bits {
-            false => RFFIE1_A::DISABLED,
-            true => RFFIE1_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == RFFIE1_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == RFFIE1_A::ENABLED
-    }
-}
-impl core::ops::Deref for RFFIE1_R {
-    type Target = crate::FieldReader<bool, RFFIE1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RFFIE1_R = RFFIE0_R;
 #[doc = "Field `RFFIE1` writer - Receive FIFO1 full interrupt enable"]
 pub struct RFFIE1_W<'a> {
     w: &'a mut W,
@@ -779,52 +697,10 @@ impl<'a> RFFIE1_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO1 not empty interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum RFNEIE1_A {
-    #[doc = "0: Receive FIFO not empty interrupt is disabled"]
-    DISABLED = 0,
-    #[doc = "1: Receive FIFO not empty interrupt is enabled"]
-    ENABLED = 1,
-}
-impl From<RFNEIE1_A> for bool {
-    #[inline(always)]
-    fn from(variant: RFNEIE1_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Receive FIFO1 not empty interrupt enable"]
+pub type RFNEIE1_A = RFNEIE0_A;
 #[doc = "Field `RFNEIE1` reader - Receive FIFO1 not empty interrupt enable"]
-pub struct RFNEIE1_R(crate::FieldReader<bool, RFNEIE1_A>);
-impl RFNEIE1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        RFNEIE1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> RFNEIE1_A {
-        match self.bits {
-            false => RFNEIE1_A::DISABLED,
-            true => RFNEIE1_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == RFNEIE1_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == RFNEIE1_A::ENABLED
-    }
-}
-impl core::ops::Deref for RFNEIE1_R {
-    type Target = crate::FieldReader<bool, RFNEIE1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RFNEIE1_R = RFNEIE0_R;
 #[doc = "Field `RFNEIE1` writer - Receive FIFO1 not empty interrupt enable"]
 pub struct RFNEIE1_W<'a> {
     w: &'a mut W,
@@ -862,10 +738,52 @@ impl<'a> RFNEIE1_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO0 overfull interrupt enable"]
-pub type RFOIE0_A = RFOIE1_A;
+#[doc = "Receive FIFO0 overfull interrupt enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum RFOIE0_A {
+    #[doc = "0: Receive FIFO overfull interrupt is disabled"]
+    DISABLED = 0,
+    #[doc = "1: Receive FIFO overfull interrupt is enabled"]
+    ENABLED = 1,
+}
+impl From<RFOIE0_A> for bool {
+    #[inline(always)]
+    fn from(variant: RFOIE0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `RFOIE0` reader - Receive FIFO0 overfull interrupt enable"]
-pub type RFOIE0_R = RFOIE1_R;
+pub struct RFOIE0_R(crate::FieldReader<bool, RFOIE0_A>);
+impl RFOIE0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RFOIE0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> RFOIE0_A {
+        match self.bits {
+            false => RFOIE0_A::DISABLED,
+            true => RFOIE0_A::ENABLED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `DISABLED`"]
+    #[inline(always)]
+    pub fn is_disabled(&self) -> bool {
+        **self == RFOIE0_A::DISABLED
+    }
+    #[doc = "Checks if the value of the field is `ENABLED`"]
+    #[inline(always)]
+    pub fn is_enabled(&self) -> bool {
+        **self == RFOIE0_A::ENABLED
+    }
+}
+impl core::ops::Deref for RFOIE0_R {
+    type Target = crate::FieldReader<bool, RFOIE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `RFOIE0` writer - Receive FIFO0 overfull interrupt enable"]
 pub struct RFOIE0_W<'a> {
     w: &'a mut W,
@@ -903,10 +821,52 @@ impl<'a> RFOIE0_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO0 full interrupt enable"]
-pub type RFFIE0_A = RFFIE1_A;
+#[doc = "Receive FIFO0 full interrupt enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum RFFIE0_A {
+    #[doc = "0: Receive FIFO full interrupt is disabled"]
+    DISABLED = 0,
+    #[doc = "1: Receive FIFO full interrupt is enabled"]
+    ENABLED = 1,
+}
+impl From<RFFIE0_A> for bool {
+    #[inline(always)]
+    fn from(variant: RFFIE0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `RFFIE0` reader - Receive FIFO0 full interrupt enable"]
-pub type RFFIE0_R = RFFIE1_R;
+pub struct RFFIE0_R(crate::FieldReader<bool, RFFIE0_A>);
+impl RFFIE0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RFFIE0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> RFFIE0_A {
+        match self.bits {
+            false => RFFIE0_A::DISABLED,
+            true => RFFIE0_A::ENABLED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `DISABLED`"]
+    #[inline(always)]
+    pub fn is_disabled(&self) -> bool {
+        **self == RFFIE0_A::DISABLED
+    }
+    #[doc = "Checks if the value of the field is `ENABLED`"]
+    #[inline(always)]
+    pub fn is_enabled(&self) -> bool {
+        **self == RFFIE0_A::ENABLED
+    }
+}
+impl core::ops::Deref for RFFIE0_R {
+    type Target = crate::FieldReader<bool, RFFIE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `RFFIE0` writer - Receive FIFO0 full interrupt enable"]
 pub struct RFFIE0_W<'a> {
     w: &'a mut W,
@@ -944,10 +904,52 @@ impl<'a> RFFIE0_W<'a> {
         self.w
     }
 }
-#[doc = "Receive FIFO0 not empty interrupt enable"]
-pub type RFNEIE0_A = RFNEIE1_A;
+#[doc = "Receive FIFO0 not empty interrupt enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum RFNEIE0_A {
+    #[doc = "0: Receive FIFO not empty interrupt is disabled"]
+    DISABLED = 0,
+    #[doc = "1: Receive FIFO not empty interrupt is enabled"]
+    ENABLED = 1,
+}
+impl From<RFNEIE0_A> for bool {
+    #[inline(always)]
+    fn from(variant: RFNEIE0_A) -> Self {
+        variant as u8 != 0
+    }
+}
 #[doc = "Field `RFNEIE0` reader - Receive FIFO0 not empty interrupt enable"]
-pub type RFNEIE0_R = RFNEIE1_R;
+pub struct RFNEIE0_R(crate::FieldReader<bool, RFNEIE0_A>);
+impl RFNEIE0_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RFNEIE0_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> RFNEIE0_A {
+        match self.bits {
+            false => RFNEIE0_A::DISABLED,
+            true => RFNEIE0_A::ENABLED,
+        }
+    }
+    #[doc = "Checks if the value of the field is `DISABLED`"]
+    #[inline(always)]
+    pub fn is_disabled(&self) -> bool {
+        **self == RFNEIE0_A::DISABLED
+    }
+    #[doc = "Checks if the value of the field is `ENABLED`"]
+    #[inline(always)]
+    pub fn is_enabled(&self) -> bool {
+        **self == RFNEIE0_A::ENABLED
+    }
+}
+impl core::ops::Deref for RFNEIE0_R {
+    type Target = crate::FieldReader<bool, RFNEIE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `RFNEIE0` writer - Receive FIFO0 not empty interrupt enable"]
 pub struct RFNEIE0_W<'a> {
     w: &'a mut W,
@@ -1212,6 +1214,7 @@ impl W {
         TMEIE_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
